@@ -1,6 +1,6 @@
 package UvT::Email::Template;
 
-# $Id: Template.pm 39392 2013-05-13 10:09:55Z wsl $
+# $Id: Template.pm 39393 2013-05-13 11:07:56Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/uvt-email-template/lib/UvT/Email/Template.pm $
 
 # formatteer een XML-bericht tot een multipart/alternative MIME
@@ -69,7 +69,7 @@ sub wrap {
 	my ($init, $cont, $text) = @_;
 	my @lines = split(/(\n)/, $text);
 	my $pfx = $init;
-	my $res;
+	my $res = '';
 	while(@lines) {
 		my $line = shift(@lines);
 		my $eol = shift(@lines) // '';
@@ -131,7 +131,7 @@ sub format_strong {
 
 sub format_em {
 	my $text = $self->nodes_to_text(shift->childNodes);
-#		return "/$text/";
+#	return "/$text/";
 	$text =~ s/([^_\n])/$1\010_/g;
 	return $text;
 }
@@ -201,7 +201,7 @@ sub list_to_text {
 	my ($fmt, $node) = @_;
 	my $width = length(sprintf($fmt, 0));
 	my $indent = " "x$width;
-	my $index;
+	my $index = 0;
 	my $text = '';
 	foreach my $item ($node->findnodes('li')) {
 		$index++;
